<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Custom Form Newsletter Subscription
 */

namespace Amasty\CustomFormNewsletterSubscription\Model\Form\Rendering\FormJson;

use Amasty\Customform\Api\Data\FormInterface;
use Amasty\Customform\Model\Form\Rendering\FormJson\ModifierInterface;
use Amasty\Customform\Model\Utils\CustomerInfo;
use Amasty\CustomFormNewsletterSubscription\Model\ConfigProvider;
use Magento\Framework\Module\Manager as ModuleManager;

class AddSubscriptionField implements ModifierInterface
{
    public const SUBSCRIPTION_FIELD = 'subscription';

    /**
     * @var ModuleManager
     */
    private $moduleManager;

    /**
     * @var ConfigProvider
     */
    private $configProvider;

    /**
     * @var CustomerInfo
     */
    private $customerInfo;

    public function __construct(
        ModuleManager $moduleManager,
        ConfigProvider $configProvider,
        CustomerInfo $customerInfo
    ) {
        $this->moduleManager = $moduleManager;
        $this->configProvider = $configProvider;
        $this->customerInfo = $customerInfo;
    }

    public function execute(FormInterface $form, array $formJson): array
    {
        if ($this->moduleManager->isEnabled('Magento_Newsletter')
            && ($this->configProvider->isNewsletterSubscribeAllowedForGuest() || $this->customerInfo->isLoggedIn())
            && $form->isSubscriptionEnabled()
            && $form->getEmailField()
        ) {
            $subscriptionCheckboxField = [
                'type' => 'single-checkbox',
                'name' => self::SUBSCRIPTION_FIELD,
                'values' => [[
                    'label' => '',
                    'value' => 1
                ]],
                'label' => __($form->getSubscriptionText()),
                'className' => 'amform-checkbox',
                'layout' => 'one'
            ];
            if ($form->isSubscriptionRequired()) {
                $subscriptionCheckboxField['required'] = true;
            }
            $formJson[array_key_last($formJson)][] = $subscriptionCheckboxField;
        }

        return $formJson;
    }
}
